Attribution
===========

The `rock sql` REPL is heavily derived from the https://github.com/dbcli/pgcli project.
Our sincere gratitude and admiration to the authors and contributors of that project.

